@@ -1,6 +1,6 @@
 # --
 # Kernel/Modules/AdminDynamicField.pm - provides a dynamic fields view for admins
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -18,9 +18,6 @@ use Kernel::System::CheckItem;
 use Kernel::System::DynamicField;
 use Kernel::System::DynamicField::Backend;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.22 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -328,18 +325,15 @@ sub _DynamicFieldsListShow {
                 );
 
                 # get the object type display name
-                my $ObjectTypeName
-                    = $Self->{ObjectTypeConfig}->{ $DynamicFieldData->{ObjectType} }->{DisplayName}
+                my $ObjectTypeName = $Self->{ObjectTypeConfig}->{ $DynamicFieldData->{ObjectType} }->{DisplayName}
                     || $DynamicFieldData->{ObjectType};
 
                 # get the field type display name
-                my $FieldTypeName
-                    = $Self->{FieldTypeConfig}->{ $DynamicFieldData->{FieldType} }->{DisplayName}
+                my $FieldTypeName = $Self->{FieldTypeConfig}->{ $DynamicFieldData->{FieldType} }->{DisplayName}
                     || $DynamicFieldData->{FieldType};
 
                 # get the field backend dialog
-                my $ConfigDialog
-                    = $Self->{FieldTypeConfig}->{ $DynamicFieldData->{FieldType} }->{ConfigDialog}
+                my $ConfigDialog = $Self->{FieldTypeConfig}->{ $DynamicFieldData->{FieldType} }->{ConfigDialog}
                     || '';
 
                 # print each dynamic field row
