@@ -1,6 +1,6 @@
 # --
 # Kernel/Modules/AdminDynamicFieldDropdown.pm - provides a dynamic fields text config view for admins
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -127,7 +127,7 @@ sub _AddAction {
     if ( $GetParam{Name} ) {
 
         # check if name is alphanumeric
-        if ( $GetParam{Name} !~ m{\A ( ?: [a-zA-Z] | \d )+ \z}xms ) {
+        if ( $GetParam{Name} !~ m{\A (?: [a-zA-Z] | \d )+ \z}xms ) {
 
             # add server error error class
             $Errors{NameServerError} = 'ServerError';
@@ -156,7 +156,7 @@ sub _AddAction {
     if ( $GetParam{FieldOrder} ) {
 
         # check if field order is numeric and positive
-        if ( $GetParam{FieldOrder} !~ m{\A ( ?: \d )+ \z}xms ) {
+        if ( $GetParam{FieldOrder} !~ m{\A (?: \d )+ \z}xms ) {
 
             # add server error error class
             $Errors{FieldOrderServerError}        = 'ServerError';
@@ -361,7 +361,7 @@ sub _ChangeAction {
     if ( $GetParam{Name} ) {
 
         # check if name is lowercase
-        if ( $GetParam{Name} !~ m{\A ( ?: [a-zA-Z] | \d )+ \z}xms ) {
+        if ( $GetParam{Name} !~ m{\A (?: [a-zA-Z] | \d )+ \z}xms ) {
 
             # add server error error class
             $Errors{NameServerError} = 'ServerError';
@@ -407,7 +407,7 @@ sub _ChangeAction {
     if ( $GetParam{FieldOrder} ) {
 
         # check if field order is numeric and positive
-        if ( $GetParam{FieldOrder} !~ m{\A ( ?: \d )+ \z}xms ) {
+        if ( $GetParam{FieldOrder} !~ m{\A (?: \d )+ \z}xms ) {
 
             # add server error error class
             $Errors{FieldOrderServerError}        = 'ServerError';
@@ -606,8 +606,7 @@ sub _ShowScreen {
 
                 # if the original value was empty it has been changed in _GetParams to a predefined
                 # string and need to be set to the original value again
-                $KeyClone
-                    = $Param{'PossibleValueErrors'}->{'KeyDuplicateError'}->{$Key};
+                $KeyClone = $Param{'PossibleValueErrors'}->{'KeyDuplicateError'}->{$Key};
 
                 # set the error class
                 $KeyError     = 'ServerError';
