@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/AdminProcessManagementPath.pm - process management path
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
-# --
-# $Id: AdminProcessManagementPath.pm,v 1.11 2013/01/23 15:44:26 cr Exp $
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -24,9 +22,6 @@ use Kernel::System::ProcessManagement::DB::TransitionAction;
 
 use Kernel::System::VariableCheck qw(:all);
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.11 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -45,12 +40,11 @@ sub new {
     }
 
     # create additional objects
-    $Self->{JSONObject}       = Kernel::System::JSON->new( %{$Self} );
-    $Self->{ProcessObject}    = Kernel::System::ProcessManagement::DB::Process->new( %{$Self} );
-    $Self->{EntityObject}     = Kernel::System::ProcessManagement::DB::Entity->new( %{$Self} );
-    $Self->{TransitionObject} = Kernel::System::ProcessManagement::DB::Transition->new( %{$Self} );
-    $Self->{TransitionActionObject}
-        = Kernel::System::ProcessManagement::DB::TransitionAction->new( %{$Self} );
+    $Self->{JSONObject}             = Kernel::System::JSON->new( %{$Self} );
+    $Self->{ProcessObject}          = Kernel::System::ProcessManagement::DB::Process->new( %{$Self} );
+    $Self->{EntityObject}           = Kernel::System::ProcessManagement::DB::Entity->new( %{$Self} );
+    $Self->{TransitionObject}       = Kernel::System::ProcessManagement::DB::Transition->new( %{$Self} );
+    $Self->{TransitionActionObject} = Kernel::System::ProcessManagement::DB::TransitionAction->new( %{$Self} );
 
     return $Self;
 }
@@ -70,8 +64,7 @@ sub Run {
     );
 
     # get available transitions
-    $Self->{TransitionList}
-        = $Self->{TransitionObject}->TransitionListGet( UserID => $Self->{UserID} );
+    $Self->{TransitionList} = $Self->{TransitionObject}->TransitionListGet( UserID => $Self->{UserID} );
 
     # get available transition actions
     $Self->{TransitionActionList}
@@ -86,7 +79,7 @@ sub Run {
         my $PathData;
 
         # get parameter from web browser
-        my $GetParam = $Self->_GetParams;
+        my $GetParam = $Self->_GetParams();
 
         $PathData->{ProcessEntityID}    = $GetParam->{ProcessEntityID}    || $GetParam->{ID};
         $PathData->{TransitionEntityID} = $GetParam->{TransitionEntityID} || $GetParam->{EntityID};
@@ -113,7 +106,7 @@ sub Run {
         my $TransferData;
 
         # get parameter from web browser
-        my $GetParam = $Self->_GetParams;
+        my $GetParam = $Self->_GetParams();
 
         # merge changed data into process config
         $TransferData->{ProcessEntityID}    = $GetParam->{ProcessEntityID};
@@ -141,8 +134,7 @@ sub Run {
 
         # insert the "new" transition entry into path hash
         $ProcessData->{ $TransferData->{ProcessEntityID} }->{Path}
-            ->{ $DataToMerge->{StartActivityEntityID} }->{ $DataToMerge->{NewTransitionEntityID} }
-            = {
+            ->{ $DataToMerge->{StartActivityEntityID} }->{ $DataToMerge->{NewTransitionEntityID} } = {
             TransitionAction => $DataToMerge->{NewTransitionActions},
             ActivityEntityID => $DataToMerge->{NewTransitionActivityID},
             };
@@ -160,20 +152,45 @@ sub Run {
         # check if needed to open another window or if popup should go back
         if ( $Redirect && $Redirect eq '1' ) {
 
+            my $RedirectAction    = $Self->{ParamObject}->GetParam( Param => 'PopupRedirectAction' )    || '';
+            my $RedirectSubaction = $Self->{ParamObject}->GetParam( Param => 'PopupRedirectSubaction' ) || '';
+            my $RedirectID        = $Self->{ParamObject}->GetParam( Param => 'PopupRedirectID' )        || '';
+            my $RedirectEntityID  = $Self->{ParamObject}->GetParam( Param => 'PopupRedirectEntityID' )  || '';
+
+            # when redirecting to the transition dialog, we need the new TransitionID
+            # because the ID was possibly changed in this dialog
+            # the value is stored in data-entity
+            # when redirecting to the transition action dialog, data-entity contains
+            # the transition action ID, but still we need the transition ID for going back
+
+            my $EntityID;
+
+            if (
+                $RedirectSubaction eq 'TransitionActionEdit'
+                || $RedirectSubaction eq 'TransitionActionNew'
+                )
+            {
+                $EntityID = $TransferData->{TransitionEntityID};
+            }
+            elsif ( $RedirectSubaction eq 'TransitionEdit' ) {
+                $EntityID = $RedirectEntityID;
+            }
+
             $Self->_PushSessionScreen(
-                ID              => $TransferData->{ProcessEntityID},      # abuse!
-                EntityID        => $TransferData->{TransitionEntityID},
+                ID              => $TransferData->{ProcessEntityID},    # abuse!
+                EntityID        => $EntityID,
                 StartActivityID => $GetParam->{StartActivityID},
-                Subaction       => 'PathEdit'                             # always use edit screen
+                Subaction       => 'PathEdit'                           # always use edit screen
             );
 
-            my $RedirectAction
-                = $Self->{ParamObject}->GetParam( Param => 'PopupRedirectAction' ) || '';
-            my $RedirectSubaction
-                = $Self->{ParamObject}->GetParam( Param => 'PopupRedirectSubaction' ) || '';
-            my $RedirectID = $Self->{ParamObject}->GetParam( Param => 'PopupRedirectID' ) || '';
-            my $RedirectEntityID
-                = $Self->{ParamObject}->GetParam( Param => 'PopupRedirectEntityID' ) || '';
+            # get transition id
+            if ( $RedirectAction eq 'AdminProcessManagementTransition' && !$RedirectID ) {
+                my $Transition = $Self->{TransitionObject}->TransitionGet(
+                    EntityID => $RedirectEntityID,
+                    UserID   => $Self->{UserID},
+                );
+                $RedirectID = $Transition->{ID};
+            }
 
             # redirect to another popup window
             return $Self->_PopupResponse(
@@ -182,7 +199,7 @@ sub Run {
                     Action    => $RedirectAction,
                     Subaction => $RedirectSubaction,
                     ID        => $RedirectID,
-                    EntityID  => $RedirectID,
+                    EntityID  => $RedirectEntityID,
                 },
                 ConfigJSON => $ConfigJSON,
             );
@@ -260,7 +277,7 @@ sub _ShowEdit {
         );
     }
 
-    # localize available actvity dialogs
+    # localize available activity dialogs
     my @AvailableTransitionActions = @{ $Self->{TransitionActionList} };
 
     # create available transition actions lookup tables based on entity id
@@ -271,8 +288,7 @@ sub _ShowEdit {
         next TRANSITIONACTION if !$TransitionActionConfig;
         next TRANSITIONACTION if !$TransitionActionConfig->{EntityID};
 
-        $AvailableTransitionActionsLookup{ $TransitionActionConfig->{EntityID} }
-            = $TransitionActionConfig;
+        $AvailableTransitionActionsLookup{ $TransitionActionConfig->{EntityID} } = $TransitionActionConfig;
     }
 
     # collect possible transitions and build selection
@@ -286,6 +302,7 @@ sub _ShowEdit {
         Name        => "Transition",
         ID          => "Transition",
         Sort        => 'AlphanumericKey',
+        Title       => $Self->{LayoutObject}->{LanguageObject}->Get("Transition"),
         Translation => 1,
         Class       => 'W50pc',
     );
