@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/AdminUserGroup.pm - to add/update/delete groups <-> users
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
-# --
-# $Id: AdminUserGroup.pm,v 1.56 2011-12-23 13:37:00 mg Exp $
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,9 +12,6 @@ package Kernel::Modules::AdminUserGroup;
 use strict;
 use warnings;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.56 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -63,7 +58,7 @@ sub Run {
             %Types,
             Data => \%GroupData,
             ID   => $UserData{UserID},
-            Name => $UserData{UserLogin},
+            Name => "$UserData{UserFirstname} $UserData{UserLastname} ($UserData{UserLogin})",
             Type => 'User',
         );
         $Output .= $Self->{LayoutObject}->Footer();
@@ -83,7 +78,7 @@ sub Run {
         my %UserData = $Self->{UserObject}->UserList( Valid => 1 );
 
         # get user name
-        for my $UserID ( keys %UserData ) {
+        for my $UserID ( sort keys %UserData ) {
             my $Name = $Self->{UserObject}->UserName( UserID => $UserID );
             next if !$Name;
             $UserData{$UserID} .= " ($Name)";
@@ -133,8 +128,8 @@ sub Run {
         # get group data
         my %UserData = $Self->{UserObject}->UserList( Valid => 1 );
         my %NewPermission;
-        for my $UserID ( keys %UserData ) {
-            for my $Permission ( keys %Permissions ) {
+        for my $UserID ( sort keys %UserData ) {
+            for my $Permission ( sort keys %Permissions ) {
                 $NewPermission{$Permission} = 0;
                 my @Array = @{ $Permissions{$Permission} };
                 for my $ID (@Array) {
@@ -173,8 +168,8 @@ sub Run {
         # get group data
         my %GroupData = $Self->{GroupObject}->GroupList( Valid => 1 );
         my %NewPermission;
-        for my $GroupID ( keys %GroupData ) {
-            for my $Permission ( keys %Permissions ) {
+        for my $GroupID ( sort keys %GroupData ) {
+            for my $Permission ( sort keys %Permissions ) {
                 $NewPermission{$Permission} = 0;
                 my @Array = @{ $Permissions{$Permission} };
                 for my $ID (@Array) {
@@ -210,12 +205,17 @@ sub _Change {
     my $Type   = $Param{Type} || 'User';
     my $NeType = $Type eq 'Group' ? 'User' : 'Group';
 
-    my %VisibleType = ( Group => 'Group', User => 'Agent', );
+    my %VisibleType = (
+        Group => 'Group',
+        User  => 'Agent',
+    );
 
     $Self->{LayoutObject}->Block( Name => 'Overview' );
     $Self->{LayoutObject}->Block( Name => 'ActionList' );
     $Self->{LayoutObject}->Block( Name => 'ActionOverview' );
-    $Self->{LayoutObject}->Block( Name => 'ChangeReference', );
+    $Self->{LayoutObject}->Block(
+        Name => 'ChangeReference',
+    );
     $Self->{LayoutObject}->Block(
         Name => 'Change',
         Data => {
@@ -295,7 +295,7 @@ sub _Overview {
     my %UserData = $Self->{UserObject}->UserList( Valid => 1 );
 
     # get user name
-    for my $UserID ( keys %UserData ) {
+    for my $UserID ( sort keys %UserData ) {
         my $Name = $Self->{UserObject}->UserName( UserID => $UserID );
         next if !$Name;
         $UserData{$UserID} .= " ($Name)";
