@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/AgentLinkObject.pm - to link objects
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: AgentLinkObject.pm,v 1.68 2012/11/20 14:46:42 mh Exp $
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -16,9 +14,6 @@ use warnings;
 
 use Kernel::System::LinkObject;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.68 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -63,6 +58,35 @@ sub Run {
         );
     }
 
+    # check if this is a temporary ticket link used while creating a new ticket
+    my $TemporarySourceTicketLink;
+    if (
+        $Form{Mode} eq 'Temporary'
+        && $Form{SourceObject} eq 'Ticket'
+        && $Form{SourceKey} =~ m{ \A \d+ \. \d+ }xms
+        )
+    {
+        $TemporarySourceTicketLink = 1;
+    }
+
+    # do the permission check only if it is no temporary ticket link used while creating a new ticket
+    if ( !$TemporarySourceTicketLink ) {
+
+        # permission check
+        my $Permission = $Self->{LinkObject}->ObjectPermission(
+            Object => $Form{SourceObject},
+            Key    => $Form{SourceKey},
+            UserID => $Self->{UserID},
+        );
+
+        if ( !$Permission ) {
+            return $Self->{LayoutObject}->NoPermission(
+                Message    => 'You need ro permission!',
+                WithHeader => 'yes',
+            );
+        }
+    }
+
     # get form params
     $Form{TargetIdentifier} = $Self->{ParamObject}->GetParam( Param => 'TargetIdentifier' )
         || $Form{SourceObject};
@@ -140,6 +164,14 @@ sub Run {
                 next IDENTIFIER if !$Target[1];    # TargetKey
                 next IDENTIFIER if !$Target[2];    # LinkType
 
+                my $DeletePermission = $Self->{LinkObject}->ObjectPermission(
+                    Object => $Target[0],
+                    Key    => $Target[1],
+                    UserID => $Self->{UserID},
+                );
+
+                next IDENTIFIER if !$DeletePermission;
+
                 # delete link from database
                 my $Success = $Self->{LinkObject}->LinkDelete(
                     Object1 => $Form{SourceObject},
@@ -336,6 +368,30 @@ sub Run {
                         $TargetKey    = $TargetKeyOrg;
                     }
 
+                    # check if this is a temporary ticket link used while creating a new ticket
+                    my $TemporaryTargetTicketLink;
+                    if (
+                        $Form{Mode} eq 'Temporary'
+                        && $TargetObject eq 'Ticket'
+                        && $TargetKey =~ m{ \A \d+ \. \d+ }xms
+                        )
+                    {
+                        $TemporaryTargetTicketLink = 1;
+                    }
+
+                    # do the permission check only if it is no temporary ticket link
+                    # used while creating a new ticket
+                    if ( !$TemporaryTargetTicketLink ) {
+
+                        my $AddPermission = $Self->{LinkObject}->ObjectPermission(
+                            Object => $TargetObject,
+                            Key    => $TargetKey,
+                            UserID => $Self->{UserID},
+                        );
+
+                        next TARGETKEYORG if !$AddPermission;
+                    }
+
                     # add links to database
                     my $Success = $Self->{LinkObject}->LinkAdd(
                         SourceObject => $SourceObject,
@@ -550,8 +606,7 @@ sub Run {
 
         # add search result to link list
         if ( $SearchList && $SearchList->{ $Form{TargetObject} } ) {
-            $LinkListWithData->{ $Form{TargetObject} }->{NOTLINKED}
-                = $SearchList->{ $Form{TargetObject} }->{NOTLINKED};
+            $LinkListWithData->{ $Form{TargetObject} }->{NOTLINKED} = $SearchList->{ $Form{TargetObject} }->{NOTLINKED};
         }
 
         # get possible types list
