@@ -1,6 +1,6 @@
 # --
 # Kernel/Modules/CustomerTicketMessage.pm - to handle customer messages
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -101,8 +101,7 @@ sub Run {
         next DYNAMICFIELD if !$DynamicField;
         next DYNAMICFIELD if !$DynamicFieldValues{$DynamicField};
 
-        $DynamicFieldACLParameters{ 'DynamicField_' . $DynamicField }
-            = $DynamicFieldValues{$DynamicField};
+        $DynamicFieldACLParameters{ 'DynamicField_' . $DynamicField } = $DynamicFieldValues{$DynamicField};
     }
     $GetParam{DynamicField} = \%DynamicFieldACLParameters;
 
@@ -160,8 +159,7 @@ sub Run {
                     my %Filter = $Self->{TicketObject}->TicketAclData();
 
                     # convert Filer key => key back to key => value using map
-                    %{$PossibleValuesFilter}
-                        = map { $_ => $DynamicFieldConfig->{Config}->{PossibleValues}->{$_} }
+                    %{$PossibleValuesFilter} = map { $_ => $DynamicFieldConfig->{Config}->{PossibleValues}->{$_} }
                         keys %Filter;
                 }
             }
@@ -193,6 +191,10 @@ sub Run {
         return $Output;
     }
     elsif ( $Self->{Subaction} eq 'StoreNew' ) {
+
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck( Type => 'Customer' );
+
         my $NextScreen = $Self->{Config}->{NextScreenAfterNewTicket};
         my %Error;
 
@@ -206,8 +208,7 @@ sub Run {
 
         # fallback, if no destination is given
         if ( !$NewQueueID ) {
-            my $Queue
-                = $Self->{ParamObject}->GetParam( Param => 'Queue' )
+            my $Queue = $Self->{ParamObject}->GetParam( Param => 'Queue' )
                 || $Self->{Config}->{'QueueDefault'}
                 || '';
             if ($Queue) {
@@ -301,8 +302,7 @@ sub Run {
                     my %Filter = $Self->{TicketObject}->TicketAclData();
 
                     # convert Filer key => key back to key => value using map
-                    %{$PossibleValuesFilter}
-                        = map { $_ => $DynamicFieldConfig->{Config}->{PossibleValues}->{$_} }
+                    %{$PossibleValuesFilter} = map { $_ => $DynamicFieldConfig->{Config}->{PossibleValues}->{$_} }
                         keys %Filter;
                 }
             }
@@ -353,10 +353,12 @@ sub Run {
                 );
         }
 
-        # rewrap body if rich text is used
-        if ( $Self->{LayoutObject}->{BrowserRichText} && $GetParam{Body} ) {
-            $GetParam{Body}
-                =~ s/(^>.+|.{4,$Self->{ConfigObject}->Get('Ticket::Frontend::TextAreaNote')})(?:\s|\z)/$1\n/gm;
+        # rewrap body if no rich text is used
+        if ( $GetParam{Body} && !$Self->{LayoutObject}->{BrowserRichText} ) {
+            $GetParam{Body} = $Self->{LayoutObject}->WrapPlainText(
+                MaxCharacters => $Self->{ConfigObject}->Get('Ticket::Frontend::TextAreaNote'),
+                PlainText     => $GetParam{Body},
+            );
         }
 
         # check queue
@@ -364,6 +366,28 @@ sub Run {
             $Error{QueueInvalid} = 'ServerError';
         }
 
+        # prevent tamper with (Queue/Dest), see bug#9408
+        if ( $NewQueueID && !$IsUpload ) {
+
+            # get the original list of queues to display
+            my $Tos = $Self->_GetTos(
+                %GetParam,
+                %ACLCompatGetParam,
+                QueueID => $NewQueueID,
+            );
+
+            # check if current selected QueueID exists in the list of queues,\
+            # otherwise rise an error
+            if ( !$Tos->{$NewQueueID} ) {
+                $Error{QueueInvalid} = 'ServerError';
+            }
+
+            # set the correct queue name in $To if it was altered
+            if ( $To ne $Tos->{$NewQueueID} ) {
+                $To = $Tos->{$NewQueueID}
+            }
+        }
+
         # check subject
         if ( !$GetParam{Subject} && !$IsUpload ) {
             $Error{SubjectInvalid} = 'ServerError';
@@ -748,8 +772,7 @@ sub _GetServices {
     return \%Service if !$Param{QueueID} && !$Param{TicketID};
 
     # get options for default services for unknown customers
-    my $DefaultServiceUnknownCustomer
-        = $Self->{ConfigObject}->Get('Ticket::Service::Default::UnknownCustomer');
+    my $DefaultServiceUnknownCustomer = $Self->{ConfigObject}->Get('Ticket::Service::Default::UnknownCustomer');
 
     # get service list
     if ( $Param{CustomerUserID} || $DefaultServiceUnknownCustomer ) {
@@ -787,7 +810,10 @@ sub _GetTos {
     my $Module = $Self->{ConfigObject}->Get('CustomerPanel::NewTicketQueueSelectionModule')
         || 'Kernel::Output::HTML::CustomerNewTicketQueueSelectionGeneric';
     if ( $Self->{MainObject}->Require($Module) ) {
-        my $Object = $Module->new( %{$Self}, Debug => $Self->{Debug}, );
+        my $Object = $Module->new(
+            %{$Self},
+            Debug => $Self->{Debug},
+        );
 
         # log loaded module
         if ( $Self->{Debug} > 1 ) {
@@ -796,7 +822,13 @@ sub _GetTos {
                 Message  => "Module: $Module loaded!",
             );
         }
-        %NewTos = ( $Object->Run( Env => $Self, ACLParams => \%Param ), ( '', => '-' ) );
+        %NewTos = (
+            $Object->Run(
+                Env       => $Self,
+                ACLParams => \%Param
+            ),
+            ( '', => '-' )
+        );
     }
     else {
         return $Self->{LayoutObject}->FatalDie(
@@ -826,7 +858,10 @@ sub _MaskNew {
         my $Module = $Self->{ConfigObject}->Get('CustomerPanel::NewTicketQueueSelectionModule')
             || 'Kernel::Output::HTML::CustomerNewTicketQueueSelectionGeneric';
         if ( $Self->{MainObject}->Require($Module) ) {
-            my $Object = $Module->new( %{$Self}, Debug => $Self->{Debug}, );
+            my $Object = $Module->new(
+                %{$Self},
+                Debug => $Self->{Debug},
+            );
 
             # log loaded module
             if ( $Self->{Debug} > 1 ) {
@@ -835,7 +870,13 @@ sub _MaskNew {
                     Message  => "Module: $Module loaded!",
                 );
             }
-            %NewTos = ( $Object->Run( Env => $Self, ACLParams => \%Param ), ( '', => '-' ) );
+            %NewTos = (
+                $Object->Run(
+                    Env       => $Self,
+                    ACLParams => \%Param
+                ),
+                ( '', => '-' )
+            );
         }
         else {
             return $Self->{LayoutObject}->FatalError();
@@ -1055,8 +1096,7 @@ sub _GetFieldsToUpdate {
 
     # set the fields that can be updatable via AJAXUpdate
     if ( !$Param{OnlyDynamicFields} ) {
-        @UpdatableFields
-            = qw( Dest ServiceID SLAID PriorityID );
+        @UpdatableFields = qw( Dest ServiceID SLAID PriorityID );
     }
 
     # cycle trough the activated Dynamic Fields for this screen
