@@ -1,8 +1,6 @@
 # --
 # Kernel/System/CustomerAuth.pm - provides the authentication
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
-# --
-# $Id: CustomerAuth.pm,v 1.34.2.2 2011/04/01 15:21:01 mp Exp $
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,10 +11,10 @@ package Kernel::System::CustomerAuth;
 
 use strict;
 use warnings;
+
 use Kernel::System::CustomerUser;
 
-use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.34.2.2 $) [1];
+use vars qw(@ISA);
 
 =head1 NAME
 
@@ -186,32 +184,22 @@ sub Auth {
         return;
     }
 
-    # remember login attributes
-    if (%CustomerData) {
+    return $User if !%CustomerData;
 
-        # reset failed logins
-        $Self->{CustomerUserObject}->SetPreferences(
-            Key    => 'UserLoginFailed',
-            Value  => 0,
-            UserID => $CustomerData{UserLogin},
-        );
+    # reset failed logins
+    $Self->{CustomerUserObject}->SetPreferences(
+        Key    => 'UserLoginFailed',
+        Value  => 0,
+        UserID => $CustomerData{UserLogin},
+    );
 
-        # last login preferences update
-        $Self->{CustomerUserObject}->SetPreferences(
-            Key    => 'UserLastLogin',
-            Value  => $Self->{TimeObject}->SystemTime(),
-            UserID => $CustomerData{UserLogin},
-        );
+    # last login preferences update
+    $Self->{CustomerUserObject}->SetPreferences(
+        Key    => 'UserLastLogin',
+        Value  => $Self->{TimeObject}->SystemTime(),
+        UserID => $CustomerData{UserLogin},
+    );
 
-        # last login preferences update
-        $Self->{CustomerUserObject}->SetPreferences(
-            Key    => 'UserLastLoginTimestamp',
-            Value  => $Self->{TimeObject}->CurrentTimestamp(),
-            UserID => $CustomerData{UserLogin},
-        );
-    }
-
-    # return user
     return $User;
 }
 
@@ -228,9 +216,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.34.2.2 $ $Date: 2011/04/01 15:21:01 $
-
-=cut
