@@ -1,6 +1,6 @@
 # --
 # Kernel/System/GenericAgent.pm - generic agent system module
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,6 +14,7 @@ use warnings;
 
 use Kernel::System::DynamicField;
 use Kernel::System::DynamicField::Backend;
+use Kernel::System::State;
 use Kernel::System::VariableCheck qw(:all);
 
 =head1 NAME
@@ -107,6 +108,15 @@ sub new {
     # create additional objects
     $Self->{DynamicFieldObject} = Kernel::System::DynamicField->new(%Param);
     $Self->{BackendObject}      = Kernel::System::DynamicField::Backend->new(%Param);
+    $Self->{StateObject}        = Kernel::System::State->new(%Param);
+
+    my %PendingStates = $Self->{StateObject}->StateGetStatesByType(
+        StateType => [ 'pending auto', 'pending reminder' ],
+        Result    => 'HASH',
+    );
+
+    $Self->{PendingStateList} = \%PendingStates || {};
+    $Self->{CurrentSystemTime} = $Self->{TimeObject}->SystemTime();
 
     # get the dynamic fields for ticket object
     $Self->{DynamicField} = $Self->{DynamicFieldObject}->DynamicFieldListGet(
@@ -224,7 +234,10 @@ sub JobRun {
     # check needed stuff
     for (qw(Job UserID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -258,7 +271,10 @@ sub JobRun {
         my %DBJobRaw = $Self->JobGet( Name => $Param{Job} );
 
         # updated last run time
-        $Self->_JobUpdateRunTime( Name => $Param{Job}, UserID => $Param{UserID} );
+        $Self->_JobUpdateRunTime(
+            Name   => $Param{Job},
+            UserID => $Param{UserID}
+        );
 
         # rework
         for my $Key ( sort keys %DBJobRaw ) {
@@ -296,24 +312,19 @@ sub JobRun {
     DYNAMICFIELD:
     for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
         next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+        next DYNAMICFIELD
+            if !$DynamicFieldSearchTemplate{ 'Search_DynamicField_' . $DynamicFieldConfig->{Name} };
 
-        # get field value from the information extracted from Generic Agent job
-        my $Value = $Self->{BackendObject}->SearchFieldValueGet(
+        # extract the dynamic field value form the Generic Agent Job
+        my $SearchParameter = $Self->{BackendObject}->SearchFieldParameterBuild(
             DynamicFieldConfig => $DynamicFieldConfig,
             Profile            => \%DynamicFieldSearchTemplate,
-        ) || '';
+        );
 
-        if ($Value) {
-
-            # get search attibutes
-            my $SearchParameter = $Self->{BackendObject}->CommonSearchFieldParameterBuild(
-                DynamicFieldConfig => $DynamicFieldConfig,
-                Value              => $Value,
-            );
-
-            # add search attribute to the search structure
+        # set search parameter
+        if ( defined $SearchParameter ) {
             $DynamicFieldSearchParameters{ 'DynamicField_' . $DynamicFieldConfig->{Name} }
-                = $SearchParameter;
+                = $SearchParameter->{Parameter};
         }
     }
 
@@ -510,7 +521,10 @@ sub JobList {
     # check needed stuff
     for (qw()) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -538,7 +552,10 @@ sub JobGet {
     # check needed stuff
     for (qw(Name)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -606,8 +623,7 @@ sub JobGet {
                 && $Data{ $Type . 'TimeStartYear' }
                 )
             {
-                $Data{ $Type . 'TimeNewerDate' }
-                    = $Data{ $Type . 'TimeStartYear' } . '-'
+                $Data{ $Type . 'TimeNewerDate' } = $Data{ $Type . 'TimeStartYear' } . '-'
                     . $Data{ $Type . 'TimeStartMonth' } . '-'
                     . $Data{ $Type . 'TimeStartDay' }
                     . ' 00:00:01';
@@ -618,8 +634,7 @@ sub JobGet {
                 && $Data{ $Type . 'TimeStopYear' }
                 )
             {
-                $Data{ $Type . 'TimeOlderDate' }
-                    = $Data{ $Type . 'TimeStopYear' } . '-'
+                $Data{ $Type . 'TimeOlderDate' } = $Data{ $Type . 'TimeStopYear' } . '-'
                     . $Data{ $Type . 'TimeStopMonth' } . '-'
                     . $Data{ $Type . 'TimeStopDay' }
                     . ' 23:59:59';
@@ -656,7 +671,7 @@ sub JobGet {
                     $Time = $Data{ $Type . 'TimePoint' } * 60 * 24 * 30;
                 }
                 elsif ( $Data{ $Type . 'TimePointFormat' } eq 'year' ) {
-                    $Time = $Data{ $Type . 'TimePoint' } * 60 * 24 * 356;
+                    $Time = $Data{ $Type . 'TimePoint' } * 60 * 24 * 365;
                 }
                 if ( $Data{ $Type . 'TimePointStart' } eq 'Before' ) {
                     $Data{ $Type . 'TimeOlderMinutes' } = $Time;
@@ -700,7 +715,10 @@ sub JobAdd {
     # check needed stuff
     for (qw(Name Data UserID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -759,7 +777,10 @@ sub JobDelete {
     # check needed stuff
     for (qw(Name UserID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -801,7 +822,10 @@ sub _JobRunTicket {
     # check needed stuff
     for (qw(TicketID TicketNumber Config UserID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -873,6 +897,8 @@ sub _JobRunTicket {
         }
     }
 
+    my $IsPendingState;
+
     # set new state
     if ( $Param{Config}->{New}->{State} ) {
         if ( $Self->{NoticeSTDOUT} ) {
@@ -883,6 +909,8 @@ sub _JobRunTicket {
             UserID   => $Param{UserID},
             State    => $Param{Config}->{New}->{State},
         );
+
+        $IsPendingState = grep { $_ eq $Param{Config}->{New}->{State} } values %{ $Self->{PendingStateList} };
     }
     if ( $Param{Config}->{New}->{StateID} ) {
         if ( $Self->{NoticeSTDOUT} ) {
@@ -893,6 +921,41 @@ sub _JobRunTicket {
             UserID   => $Param{UserID},
             StateID  => $Param{Config}->{New}->{StateID},
         );
+
+        $IsPendingState = grep { $_ == $Param{Config}->{New}->{StateID} } keys %{ $Self->{PendingStateList} };
+    }
+
+    # set pending time, if new state is pending state
+    if ($IsPendingState) {
+        if ( $Param{Config}->{New}->{PendingTime} ) {
+
+            # pending time
+            my $PendingTime = $Param{Config}->{New}->{PendingTime};
+
+            # calculate pending time based on hours, minutes, years...
+            if ( $Param{Config}->{New}->{PendingTimeType} ) {
+                $PendingTime *= $Param{Config}->{New}->{PendingTimeType};
+            }
+
+            # add systemtime
+            $PendingTime += $Self->{CurrentSystemTime};
+
+            # get date
+            my ( $Sec, $Min, $Hour, $Day, $Month, $Year, $WeekDay ) = $Self->{TimeObject}->SystemTime2Date(
+                SystemTime => $PendingTime,
+            );
+
+            # set pending time
+            $Self->{TicketObject}->TicketPendingTimeSet(
+                Year     => $Year,
+                Month    => $Month,
+                Day      => $Day,
+                Hour     => $Hour,
+                Minute   => $Min,
+                TicketID => $Param{TicketID},
+                UserID   => $Param{UserID},
+            );
+        }
     }
 
     # set customer id and customer user
@@ -1099,7 +1162,17 @@ sub _JobRunTicket {
             TransformDates     => 0,
         );
 
-        if ( defined $Value && $Value ne '' ) {
+        # check if we got a value or an empty value if
+        # an empty value is configured as valid (PossibleNone)
+        # for the current dynamic field
+        if (
+            defined $Value
+            && (
+                $DynamicFieldConfig->{Config}->{PossibleNone}
+                || $Value ne ''
+            )
+            )
+        {
             my $Success = $Self->{BackendObject}->ValueSet(
                 DynamicFieldConfig => $DynamicFieldConfig,
                 ObjectID           => $Param{TicketID},
@@ -1158,7 +1231,10 @@ sub _JobRunTicket {
                 }
             };
             if ($@) {
-                $Self->{LogObject}->Log( Priority => 'error', Message => $@ );
+                $Self->{LogObject}->Log(
+                    Priority => 'error',
+                    Message  => $@
+                );
             }
         }
     }
@@ -1222,7 +1298,10 @@ sub _JobUpdateRunTime {
     # check needed stuff
     for (qw(Name UserID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -1235,7 +1314,11 @@ sub _JobUpdateRunTime {
     my @Data;
     while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         if ( $Row[0] =~ /^(ScheduleLastRun|ScheduleLastRunUnixTime)/ ) {
-            push @Data, { Key => $Row[0], Value => $Row[1] };
+            push @Data,
+                {
+                Key   => $Row[0],
+                Value => $Row[1]
+                };
         }
     }
 
@@ -1248,7 +1331,7 @@ sub _JobUpdateRunTime {
     );
     for my $Key ( sort keys %Insert ) {
         $Self->{DBObject}->Do(
-            SQL => 'INSERT INTO generic_agent_jobs (job_name,job_key, job_value) VALUES (?, ?, ?)',
+            SQL  => 'INSERT INTO generic_agent_jobs (job_name,job_key, job_value) VALUES (?, ?, ?)',
             Bind => [ \$Param{Name}, \$Key, \$Insert{$Key} ],
         );
     }
