@@ -1,6 +1,6 @@
 # --
 # Kernel/System/HTMLUtils.pm - creating and modifying html strings
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -84,7 +84,10 @@ sub ToAscii {
     # check needed stuff
     for (qw(String)) {
         if ( !defined $Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -560,7 +563,10 @@ sub ToHTML {
     # check needed stuff
     for (qw(String)) {
         if ( !defined $Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -595,7 +601,10 @@ sub DocumentComplete {
     # check needed stuff
     for (qw(String Charset)) {
         if ( !defined $Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -630,7 +639,10 @@ sub DocumentStrip {
     # check needed stuff
     for (qw(String)) {
         if ( !defined $Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -669,7 +681,10 @@ sub DocumentCleanup {
     # check needed stuff
     for (qw(String)) {
         if ( !defined $Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -678,7 +693,7 @@ sub DocumentCleanup {
     $Param{String} =~ s{ \A \s* <html }{<!DOCTYPE html><html}gsmix;
 
     # remove <base> tags - see bug#8880
-    $Param{String} =~ s{<base .*?>}{}xms;
+    $Param{String} =~ s{<base .*?>}{}xmsi;
 
     # replace MS Word 12 <p|div> with class "MsoNormal" by using <br/> because
     # it's not used as <p><div> (margin:0cm; margin-bottom:.0001pt;)
@@ -816,8 +831,8 @@ sub LinkQuote {
                 [a-zA-Z0-9&;=%]*                   # hash string content, this will also catch entities like &amp;
             )?
         )
-        (                                          # $4
-            ?=(?:
+        (?=                                        # $4
+            (?:
                 [\?,;!\.\)] (?: \s | $ )           # \)\s this construct is because of bug# 2450
                 | \"
                 | \]
@@ -922,7 +937,10 @@ sub Safety {
     # check needed stuff
     for (qw(String)) {
         if ( !defined $Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -944,6 +962,34 @@ sub Safety {
     my $TagStart = '(?:<|[+]ADw-)';
     my $TagEnd   = '(?:>|[+]AD4-)';
 
+    # This can also be entity-encoded to hide it from the parser.
+    #   Browsers seem to tolerate an omitted ";".
+    my $JavaScriptPrefixRegex = '
+        (?: j | &\#106[;]? | &\#x6a[;]? )
+        (?: a | &\#97[;]?  | &\#x61[;]? )
+        (?: v | &\#118[;]? | &\#x76[;]? )
+        (?: a | &\#97[;]?  | &\#x61[;]? )
+        (?: s | &\#115[;]? | &\#x73[;]? )
+        (?: c | &\#99[;]?  | &\#x63[;]? )
+        (?: r | &\#114[;]? | &\#x72[;]? )
+        (?: i | &\#105[;]? | &\#x69[;]? )
+        (?: p | &\#112[;]? | &\#x70[;]? )
+        (?: t | &\#116[;]? | &\#x74[;]? )
+    ';
+
+    my $ExpressionPrefixRegex = '
+        (?: e | &\#101[;]? | &\#x65[;]? )
+        (?: x | &\#120[;]? | &\#x78[;]? )
+        (?: p | &\#112[;]? | &\#x70[;]? )
+        (?: r | &\#114[;]? | &\#x72[;]? )
+        (?: e | &\#101[;]? | &\#x65[;]? )
+        (?: s | &\#115[;]? | &\#x73[;]? )
+        (?: s | &\#115[;]? | &\#x73[;]? )
+        (?: i | &\#105[;]? | &\#x69[;]? )
+        (?: o | &\#111[;]? | &\#x6f[;]? )
+        (?: n | &\#110[;]? | &\#x6e[;]? )
+    ';
+
     # Replace as many times as it is needed to avoid nesting tag attacks.
     do {
         $Replaced = undef;
@@ -961,7 +1007,7 @@ sub Safety {
 
             # remove style/javascript parts
             $Replaced += ${$String} =~ s{
-                $TagStart style[^>]+?javascript(.+?|) $TagEnd (.*?) $TagStart /style \s* $TagEnd
+                $TagStart style[^>]+? $JavaScriptPrefixRegex (.+?|) $TagEnd (.*?) $TagStart /style \s* $TagEnd
             }
             {}sgxim;
 
@@ -980,6 +1026,12 @@ sub Safety {
             }egsxim;
         }
 
+        # remove HTTP refirects
+        $Replaced += ${$String} =~ s{
+            $TagStart meta [^>]+? http-equiv=('|"|)refresh [^>]+? $TagEnd
+        }
+        {}sgxim;
+
         # remove <applet> tags
         if ( $Param{NoApplet} ) {
             $Replaced += ${$String} =~ s{
@@ -1022,7 +1074,7 @@ sub Safety {
 
                 # remove on action attributes
                 $Replaced += $Tag =~ s{
-                    \son.+?=(".+?"|'.+?'|.+?)($TagEnd|\s)
+                    (?:\s|/) on.+?=(".+?"|'.+?'|.+?)($TagEnd|\s)
                 }
                 {$2}sgxim;
 
@@ -1034,9 +1086,9 @@ sub Safety {
 
                 # remove javascript in a href links or src links
                 $Replaced += $Tag =~ s{
-                    ((?:\s|;)(?:background|url|src|href)=)
+                    ((?:\s|;|/)(?:background|url|src|href)=)
                     ('|"|)                                  # delimiter, can be empty
-                    (?:\s*javascript.*?)                 # javascript, followed by anything but the delimiter
+                    (?:\s* $JavaScriptPrefixRegex .*?)      # javascript, followed by anything but the delimiter
                     \2                                      # delimiter again
                     (\s|$TagEnd)
                 }
@@ -1046,13 +1098,13 @@ sub Safety {
 
                 # remove link javascript tags
                 $Replaced += $Tag =~ s{
-                    ($TagStart link .+? javascript (.+?|) $TagEnd)
+                    ($TagStart link .+? $JavaScriptPrefixRegex (.+?|) $TagEnd)
                 }
                 {}sgxim;
 
                 # remove MS CSS expressions (JavaScript embedded in CSS)
                 $Replaced += $Tag =~ s{
-                    \sstyle=("|')[^\1]*?expression[(].*?\1($TagEnd|\s)
+                    \sstyle=("|')[^\1]*? $ExpressionPrefixRegex [(].*?\1($TagEnd|\s)
                 }
                 {
                     $2;
@@ -1062,7 +1114,7 @@ sub Safety {
             # remove load tags
             if ($Param{NoIntSrcLoad} || $Param{NoExtSrcLoad}) {
                 $Tag =~ s{
-                    ($TagStart (.+?) \s src=(.+?) (\s.+?|) $TagEnd)
+                    ($TagStart (.+?) (?: \s | /) src=(.+?) (\s.+?|) $TagEnd)
                 }
                 {
                     my $URL = $3;
@@ -1113,11 +1165,17 @@ sub EmbeddedImagesExtract {
     my ( $Self, %Param ) = @_;
 
     if ( ref $Param{DocumentRef} ne 'SCALAR' || !defined ${ $Param{DocumentRef} } ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => "Need DocumentRef!" );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Need DocumentRef!"
+        );
         return;
     }
     if ( ref $Param{AttachmentsRef} ne 'ARRAY' ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => "Need DocumentRef!" );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Need DocumentRef!"
+        );
         return;
     }
 
