@@ -1,6 +1,6 @@
 # --
 # Kernel/System/Log.pm - log wapper
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -8,15 +8,16 @@
 # --
 
 package Kernel::System::Log;
+## nofilter(TidyAll::Plugin::OTRS::Perl::PODSpelling)
+## nofilter(TidyAll::Plugin::OTRS::Perl::Time)
+## nofilter(TidyAll::Plugin::OTRS::Perl::Dumper)
+## nofilter(TidyAll::Plugin::OTRS::Perl::Require)
 
 use strict;
 use warnings;
 
 use Kernel::System::Encode;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.72 $) [1];
-
 =head1 NAME
 
 Kernel::System::Log - global log interface
@@ -63,6 +64,9 @@ sub new {
         die 'Got no ConfigObject!';
     }
 
+    $Self->{ProductVersion} = $Param{ConfigObject}->Get('Product') . ' ';
+    $Self->{ProductVersion} .= $Param{ConfigObject}->Get('Version');
+
     # get system id
     my $SystemID = $Param{ConfigObject}->Get('SystemID');
 
@@ -174,9 +178,17 @@ sub Log {
 
             eval { $VersionString = $Package1->VERSION || ''; };    ## no critic
 
+            # Version is present
             if ($VersionString) {
                 $VersionString = 'v' . $VersionString;
             }
+
+            # OTRS modules do not have a version variable
+            elsif ( index( $Package1, 'Kernel::' ) > -1 ) {
+                $VersionString = $Self->{ProductVersion};
+            }
+
+            # Other modules
             else {
                 $VersionString = 'unknown version';
             }
@@ -324,8 +336,4 @@ This software comes with ABSOLUTELY NO WARRANTY. For details, see
 the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
-=head1 VERSION
-
-$Revision: 1.72 $ $Date: 2012-11-20 15:35:59 $
-
 =cut
