@@ -1,8 +1,6 @@
 # --
 # Kernel/System/MailAccount/IMAP.pm - lib for imap accounts
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
-# --
-# $Id: IMAP.pm,v 1.10 2010-08-23 04:40:47 martin Exp $
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -16,9 +14,6 @@ use warnings;
 use Net::IMAP::Simple;
 use Kernel::System::PostMaster;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.10 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -40,7 +35,10 @@ sub Connect {
     # check needed stuff
     for (qw(Login Password Host Timeout Debug)) {
         if ( !defined $Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -52,7 +50,10 @@ sub Connect {
         debug   => $Param{Debug}
     );
     if ( !$IMAPObject ) {
-        return ( Successful => 0, Message => "IMAP: Can't connect to $Param{Host}" );
+        return (
+            Successful => 0,
+            Message    => "IMAP: Can't connect to $Param{Host}"
+        );
     }
 
     # authentcation
@@ -88,13 +89,19 @@ sub _Fetch {
     # check needed stuff
     for (qw(Login Password Host Trusted QueueID)) {
         if ( !defined $Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "$_ not defined!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "$_ not defined!"
+            );
             return;
         }
     }
     for (qw(Login Password Host)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -131,8 +138,11 @@ sub _Fetch {
         return;
     }
 
+    # read folder from MailAccount configuration
+    my $IMAPFolder = $Param{IMAPFolder} || 'INBOX';
+
     my $IMAPObject = $Connect{IMAPObject};
-    my $NOM = $IMAPObject->select('INBOX') || 0;
+    my $NOM = $IMAPObject->select($IMAPFolder) || 0;
 
     # fetch messages
     if ( !$NOM ) {
@@ -160,8 +170,8 @@ sub _Fetch {
             if ( $MessageSize > $MaxEmailSize ) {
                 $Self->{LogObject}->Log(
                     Priority => 'error',
-                    Message => "$AuthType: Can't fetch email $NOM from $Param{Login}/$Param{Host}. "
-                        . "Email to big ($MessageSize KB - max $MaxEmailSize KB)!",
+                    Message  => "$AuthType: Can't fetch email $NOM from $Param{Login}/$Param{Host}. "
+                        . "Email too big ($MessageSize KB - max $MaxEmailSize KB)!",
                 );
             }
             else {
@@ -236,10 +246,10 @@ sub _Fetch {
     if ( $Debug > 0 || $FetchCounter ) {
         $Self->{LogObject}->Log(
             Priority => 'notice',
-            Message => "$AuthType: Fetched $FetchCounter email(s) from $Param{Login}/$Param{Host}.",
+            Message  => "$AuthType: Fetched $FetchCounter email(s) from $Param{Login}/$Param{Host}.",
         );
     }
-    $IMAPObject->expunge_mailbox('INBOX');
+    $IMAPObject->expunge_mailbox($IMAPFolder);
     $IMAPObject->quit();
     if ($CMD) {
         print "$AuthType: Connection to $Param{Host} closed.\n\n";
@@ -255,7 +265,10 @@ sub _ProcessFailed {
     # check needed stuff
     for (qw(Email)) {
         if ( !defined $Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "$_ not defined!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "$_ not defined!"
+            );
             return;
         }
     }
