@@ -1,6 +1,6 @@
 # --
 # Kernel/System/PostMaster/FollowUp.pm - the sub part of PostMaster.pm
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,9 +14,6 @@ use warnings;
 
 use Kernel::System::User;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.79 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -42,7 +39,10 @@ sub Run {
     # check needed stuff
     for (qw(TicketID InmailUserID GetParam Tn AutoResponseType)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -238,10 +238,9 @@ sub Run {
         if ( $GetParam{$Key} ) {
 
             # get dynamic field config
-            my $DynamicFieldGet
-                = $Self->{TicketObject}->{DynamicFieldObject}->DynamicFieldGet(
+            my $DynamicFieldGet = $Self->{TicketObject}->{DynamicFieldObject}->DynamicFieldGet(
                 ID => $DynamicFieldID,
-                );
+            );
 
             $Self->{TicketObject}->{DynamicFieldBackendObject}->ValueSet(
                 DynamicFieldConfig => $DynamicFieldGet,
@@ -393,10 +392,9 @@ sub Run {
         if ( $GetParam{$Key} ) {
 
             # get dynamic field config
-            my $DynamicFieldGet
-                = $Self->{TicketObject}->{DynamicFieldObject}->DynamicFieldGet(
+            my $DynamicFieldGet = $Self->{TicketObject}->{DynamicFieldObject}->DynamicFieldGet(
                 ID => $DynamicFieldID,
-                );
+            );
 
             $Self->{TicketObject}->{DynamicFieldBackendObject}->ValueSet(
                 DynamicFieldConfig => $DynamicFieldGet,
