@@ -1,6 +1,6 @@
 # --
 # Kernel/System/PostMaster/NewTicket.pm - sub part of PostMaster.pm
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -45,7 +45,10 @@ sub Run {
     # check needed stuff
     for my $Needed (qw(InmailUserID GetParam)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Needed!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $Needed!"
+            );
             return;
         }
     }
@@ -67,7 +70,7 @@ sub Run {
         else {
             $Self->{LogObject}->Log(
                 Priority => 'error',
-                Message => "State $GetParam{'X-OTRS-State'} does not exist, falling back to $State!"
+                Message  => "State $GetParam{'X-OTRS-State'} does not exist, falling back to $State!"
             );
         }
     }
@@ -75,8 +78,7 @@ sub Run {
     # get priority
     my $Priority = $Self->{ConfigObject}->Get('PostmasterDefaultPriority') || '3 normal';
     if ( $GetParam{'X-OTRS-Priority'} ) {
-        my $PriorityID
-            = $Self->{PriorityObject}->PriorityLookup( Priority => $GetParam{'X-OTRS-Priority'} );
+        my $PriorityID = $Self->{PriorityObject}->PriorityLookup( Priority => $GetParam{'X-OTRS-Priority'} );
         if ($PriorityID) {
             $Priority = $GetParam{'X-OTRS-Priority'};
         }
@@ -90,7 +92,9 @@ sub Run {
     }
 
     # get sender email
-    my @EmailAddresses = $Self->{ParserObject}->SplitAddressLine( Line => $GetParam{From}, );
+    my @EmailAddresses = $Self->{ParserObject}->SplitAddressLine(
+        Line => $GetParam{From},
+    );
     for my $Address (@EmailAddresses) {
         $GetParam{SenderEmailAddress} = $Self->{ParserObject}->GetEmailAddress(
             Email => $Address,
@@ -235,10 +239,9 @@ sub Run {
         if ( $GetParam{$Key} ) {
 
             # get dynamic field config
-            my $DynamicFieldGet
-                = $Self->{TicketObject}->{DynamicFieldObject}->DynamicFieldGet(
+            my $DynamicFieldGet = $Self->{TicketObject}->{DynamicFieldObject}->DynamicFieldGet(
                 ID => $DynamicFieldID,
-                );
+            );
 
             $Self->{TicketObject}->{DynamicFieldBackendObject}->ValueSet(
                 DynamicFieldConfig => $DynamicFieldGet,
@@ -257,6 +260,7 @@ sub Run {
     my %DynamicFieldListReversed = reverse %{$DynamicFieldList};
 
     # set ticket free text
+    # for backward compatibility (should be removed in a future version)
     my %Values =
         (
         'X-OTRS-TicketKey'   => 'TicketFreeKey',
@@ -288,6 +292,7 @@ sub Run {
     }
 
     # set ticket free time
+    # for backward compatibility (should be removed in a future version)
     for my $Count ( 1 .. 6 ) {
         my $Key = 'X-OTRS-TicketTime' . $Count;
         if ( $GetParam{$Key} ) {
@@ -399,10 +404,9 @@ sub Run {
         if ( $GetParam{$Key} ) {
 
             # get dynamic field config
-            my $DynamicFieldGet
-                = $Self->{TicketObject}->{DynamicFieldObject}->DynamicFieldGet(
+            my $DynamicFieldGet = $Self->{TicketObject}->{DynamicFieldObject}->DynamicFieldGet(
                 ID => $DynamicFieldID,
-                );
+            );
 
             $Self->{TicketObject}->{DynamicFieldBackendObject}->ValueSet(
                 DynamicFieldConfig => $DynamicFieldGet,
@@ -421,6 +425,7 @@ sub Run {
     %DynamicFieldListReversed = reverse %{$DynamicFieldList};
 
     # set free article text
+    # for backward compatibility (should be removed in a future version)
     %Values =
         (
         'X-OTRS-ArticleKey'   => 'ArticleFreeKey',
