@@ -1,6 +1,6 @@
 # --
 # Kernel/System/Spelling.pm - the global spelling module
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,12 +11,10 @@ package Kernel::System::Spelling;
 
 use strict;
 use warnings;
+use utf8;
 
 use Kernel::System::FileTemp;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.37 $) [1];
-
 =head1 NAME
 
 Kernel::System::Spelling - spelling lib
@@ -87,6 +85,7 @@ spelling check for some text
     my %Result = $SpellingObject->Check(
         Text          => 'Some Text to check.',
         SpellLanguage => 'en',
+        RichText      => 1, # default: 0
     );
 
     # a result could be
@@ -107,14 +106,16 @@ sub Check {
     # check needed stuff
     for (qw(Text)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
 
     # default ignored words
-    my @Ignore
-        = qw(com org de net Cc www Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec Sun Mon Tue Wed Thu Fri
+    my @Ignore = qw(com org de net Cc www Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec Sun Mon Tue Wed Thu Fri
         Sat Fwd Re DNS Date To Cc Bcc ca tm COM Co op netscape bcc jpg gif email Tel ie eg otrs suse redhat debian
         caldera php perl java html unsubscribe queue event day month year ticket
     );
@@ -176,6 +177,8 @@ sub Check {
         );
         return;
     }
+
+    $Self->{EncodeObject}->EncodeOutput( \$Param{Text} );
     print $FH $Param{Text};
 
     # aspell encoding
@@ -241,14 +244,17 @@ sub Check {
     }
 
     # drop double words and add line of double word
-    my %DoubleWords;
-    for ( sort { $a <=> $b } keys %Data ) {
-        if ( $DoubleWords{ $Data{$_}->{Word} } ) {
-            $DoubleWords{ $Data{$_}->{Word} }->{Line} .= "/" . $Data{$_}->{Line};
-            delete $Data{$_};
-        }
-        else {
-            $DoubleWords{ $Data{$_}->{Word} } = $Data{$_};
+    # bug#9914: only delete double words for non-wysiwyg spellchecker
+    if ( !$Param{RichText} ) {
+        my %DoubleWords;
+        for ( sort { $a <=> $b } keys %Data ) {
+            if ( $DoubleWords{ $Data{$_}->{Word} } ) {
+                $DoubleWords{ $Data{$_}->{Word} }->{Line} .= "/" . $Data{$_}->{Line};
+                delete $Data{$_};
+            }
+            else {
+                $DoubleWords{ $Data{$_}->{Word} } = $Data{$_};
+            }
         }
     }
 
@@ -273,7 +279,7 @@ sub Check {
 
 check if spelling check returns a system error (read log backend for error message)
 
-    my $TrueIfErro = $SpellObject->Error();
+    my $TrueIfError = $SpellObject->Error();
 
 =cut
 
@@ -295,8 +301,4 @@ This software comes with ABSOLUTELY NO WARRANTY. For details, see
 the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
-=head1 VERSION
-
-$Revision: 1.37 $ $Date: 2012-11-20 15:38:15 $
-
 =cut
