@@ -1,6 +1,6 @@
 # --
 # Kernel/System/Stats/Dynamic/TicketSolutionResponseTime.pm - stats about ticket solution and response time
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -21,9 +21,6 @@ use Kernel::System::DynamicField;
 use Kernel::System::DynamicField::Backend;
 use Kernel::System::VariableCheck qw(:all);
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.17 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -379,6 +376,26 @@ sub GetObjectAttributes {
         unshift @ObjectAttributes, \%ObjectAttribute1;
     }
 
+    if ( $Self->{ConfigObject}->Get('Ticket::ArchiveSystem') ) {
+
+        my %ObjectAttribute = (
+            Name             => 'Archive Search',
+            UseAsXvalue      => 0,
+            UseAsValueSeries => 0,
+            UseAsRestriction => 1,
+            Element          => 'SearchInArchive',
+            Block            => 'SelectField',
+            Translation      => 1,
+            Values           => {
+                ArchivedTickets    => 'Archived tickets',
+                NotArchivedTickets => 'Unarchived tickets',
+                AllTickets         => 'All tickets',
+            },
+        );
+
+        push @ObjectAttributes, \%ObjectAttribute;
+    }
+
     if ( $Self->{ConfigObject}->Get('Stats::UseAgentElementInStats') ) {
 
         my @ObjectAttributeAdd = (
@@ -483,8 +500,7 @@ sub GetObjectAttributes {
             my %Filter = $Self->{TicketObject}->TicketAclData();
 
             # convert Filer key => key back to key => value using map
-            %{$PossibleValuesFilter}
-                = map { $_ => $DynamicFieldConfig->{Config}->{PossibleValues}->{$_} } keys %Filter;
+            %{$PossibleValuesFilter} = map { $_ => $DynamicFieldConfig->{Config}->{PossibleValues}->{$_} } keys %Filter;
         }
 
         # get field html
@@ -530,6 +546,7 @@ sub GetObjectAttributes {
 sub GetStatTable {
     my ( $Self, %Param ) = @_;
     my @StatArray;
+
     if ( $Param{XValue}{Element} && $Param{XValue}{Element} eq 'KindsOfReporting' ) {
 
         for my $Row ( sort keys %{ $Param{TableStructure} } ) {
@@ -681,8 +698,7 @@ sub ImportWrapper {
                 for my $ID ( @{$Values} ) {
                     next ID if !$ID;
                     if ( $Self->{QueueObject}->QueueLookup( Queue => $ID->{Content} ) ) {
-                        $ID->{Content}
-                            = $Self->{QueueObject}->QueueLookup( Queue => $ID->{Content} );
+                        $ID->{Content} = $Self->{QueueObject}->QueueLookup( Queue => $ID->{Content} );
                     }
                     else {
                         $Self->{LogObject}->Log(
@@ -821,11 +837,10 @@ sub _ReportingValues {
                 next DYNAMICFIELD if $DynamicFieldConfig->{Name} ne $1;
 
                 # get new search parameter
-                my $DynamicFieldStatsSearchParameter
-                    = $Self->{BackendObject}->CommonSearchFieldParameterBuild(
+                my $DynamicFieldStatsSearchParameter = $Self->{BackendObject}->CommonSearchFieldParameterBuild(
                     DynamicFieldConfig => $DynamicFieldConfig,
                     Value              => $TicketSearch{$ParameterName},
-                    );
+                );
 
                 # add new search parameter
                 $TicketSearch{$ParameterName} = $DynamicFieldStatsSearchParameter;
@@ -833,6 +848,19 @@ sub _ReportingValues {
         }
     }
 
+    if ( $Self->{ConfigObject}->Get('Ticket::ArchiveSystem') ) {
+        $SearchAttributes->{SearchInArchive} ||= '';
+        if ( $SearchAttributes->{SearchInArchive} eq 'AllTickets' ) {
+            $TicketSearch{ArchiveFlags} = [ 'y', 'n' ];
+        }
+        elsif ( $SearchAttributes->{SearchInArchive} eq 'ArchivedTickets' ) {
+            $TicketSearch{ArchiveFlags} = ['y'];
+        }
+        else {
+            $TicketSearch{ArchiveFlags} = ['n'];
+        }
+    }
+
     # get the involved tickets
     my @TicketIDs = $Self->{TicketObject}->TicketSearch(
         UserID     => 1,
@@ -968,8 +996,7 @@ sub _ReportingValues {
     # min max for solution working time
     if ( $SelectedKindsOfReporting{SolutionMinWorkingTime} ) {
         if (%SolutionWorkingTime) {
-            $Reporting{SolutionMinWorkingTime}
-                = ( sort { $a <=> $b } values %SolutionWorkingTime )[0];
+            $Reporting{SolutionMinWorkingTime} = ( sort { $a <=> $b } values %SolutionWorkingTime )[0];
         }
         else {
             $Reporting{SolutionMinWorkingTime} = 0;
@@ -977,8 +1004,7 @@ sub _ReportingValues {
     }
     if ( $SelectedKindsOfReporting{SolutionMaxWorkingTime} ) {
         if (%SolutionWorkingTime) {
-            $Reporting{SolutionMaxWorkingTime}
-                = ( sort { $b <=> $a } values %SolutionWorkingTime )[0];
+            $Reporting{SolutionMaxWorkingTime} = ( sort { $b <=> $a } values %SolutionWorkingTime )[0];
         }
         else {
             $Reporting{SolutionMaxWorkingTime} = 0;
@@ -1006,8 +1032,7 @@ sub _ReportingValues {
     # min max for response working time
     if ( $SelectedKindsOfReporting{ResponseMinWorkingTime} ) {
         if (%ResponseWorkingTime) {
-            $Reporting{ResponseMinWorkingTime}
-                = ( sort { $a <=> $b } values %ResponseWorkingTime )[0];
+            $Reporting{ResponseMinWorkingTime} = ( sort { $a <=> $b } values %ResponseWorkingTime )[0];
         }
         else {
             $Reporting{ResponseMinWorkingTime} = 0;
@@ -1015,8 +1040,7 @@ sub _ReportingValues {
     }
     if ( $SelectedKindsOfReporting{ResponseMaxWorkingTime} ) {
         if (%ResponseWorkingTime) {
-            $Reporting{ResponseMaxWorkingTime}
-                = ( sort { $b <=> $a } values %ResponseWorkingTime )[0];
+            $Reporting{ResponseMaxWorkingTime} = ( sort { $b <=> $a } values %ResponseWorkingTime )[0];
         }
         else {
             $Reporting{ResponseMaxWorkingTime} = 0;
