@@ -1,8 +1,6 @@
 # --
 # Kernel/System/Ticket/Event/ForceState.pm - set state
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
-# --
-# $Id: ForceState.pm,v 1.12 2011-11-25 10:14:19 mg Exp $
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,9 +12,6 @@ package Kernel::System::Ticket::Event::ForceState;
 use strict;
 use warnings;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.12 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -41,13 +36,19 @@ sub Run {
     # check needed stuff
     for (qw(Data Event Config)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
     for (qw(TicketID)) {
         if ( !$Param{Data}->{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_ in Data!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_ in Data!"
+            );
             return;
         }
     }
@@ -62,7 +63,7 @@ sub Run {
     return 1 if lc $Ticket{Lock} ne 'lock';
 
     # set now state
-    for my $OldState ( keys %{ $Param{Config} } ) {
+    for my $OldState ( sort keys %{ $Param{Config} } ) {
         next if !$OldState;
         next if $OldState ne $Ticket{State};
 
