@@ -1,6 +1,6 @@
 # --
 # Kernel/System/User.pm - some user functions
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -18,8 +18,7 @@ use Kernel::System::CacheInternal;
 use Kernel::System::CheckItem;
 use Kernel::System::Valid;
 
-use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.126 $) [1];
+use vars qw(@ISA);
 
 =head1 NAME
 
@@ -150,7 +149,10 @@ sub GetUserData {
 
     # check needed stuff
     if ( !$Param{User} && !$Param{UserID} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need User or UserID!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'Need User or UserID!'
+        );
         return;
     }
 
@@ -170,15 +172,13 @@ sub GetUserData {
 
     my $CacheKey;
     if ( $Param{User} ) {
-        $CacheKey
-            = 'GetUserData::User::'
+        $CacheKey = 'GetUserData::User::'
             . $Param{User} . '::'
             . $Param{Valid} . '::'
             . $Param{NoOutOfOffice};
     }
     else {
-        $CacheKey
-            = 'GetUserData::UserID::'
+        $CacheKey = 'GetUserData::UserID::'
             . $Param{UserID} . '::'
             . $Param{Valid} . '::'
             . $Param{NoOutOfOffice};
@@ -255,7 +255,10 @@ sub GetUserData {
         if ( !$Hit ) {
 
             # set cache
-            $Self->{CacheInternalObject}->Set( Key => $CacheKey, Value => {} );
+            $Self->{CacheInternalObject}->Set(
+                Key   => $CacheKey,
+                Value => {}
+            );
             return;
         }
     }
@@ -320,7 +323,10 @@ sub GetUserData {
     }
 
     # set cache
-    $Self->{CacheInternalObject}->Set( Key => $CacheKey, Value => \%Data );
+    $Self->{CacheInternalObject}->Set(
+        Key   => $CacheKey,
+        Value => \%Data
+    );
 
     return %Data;
 }
@@ -347,7 +353,10 @@ sub UserAdd {
     # check needed stuff
     for (qw(UserFirstname UserLastname UserLogin UserEmail ValidID ChangeUserID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -418,10 +427,17 @@ sub UserAdd {
     );
 
     # set password
-    $Self->SetPassword( UserLogin => $Param{UserLogin}, PW => $Param{UserPw} );
+    $Self->SetPassword(
+        UserLogin => $Param{UserLogin},
+        PW        => $Param{UserPw}
+    );
 
     # set email address
-    $Self->SetPreferences( UserID => $UserID, Key => 'UserEmail', Value => $Param{UserEmail} );
+    $Self->SetPreferences(
+        UserID => $UserID,
+        Key    => 'UserEmail',
+        Value  => $Param{UserEmail}
+    );
 
     # delete cache
     my @CacheKeys = (
@@ -470,7 +486,10 @@ sub UserUpdate {
     # check needed stuff
     for (qw(UserID UserFirstname UserLastname UserLogin ValidID ChangeUserID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -509,7 +528,10 @@ sub UserUpdate {
 
     # check pw
     if ( $Param{UserPw} ) {
-        $Self->SetPassword( UserLogin => $Param{UserLogin}, PW => $Param{UserPw} );
+        $Self->SetPassword(
+            UserLogin => $Param{UserLogin},
+            PW        => $Param{UserPw}
+        );
     }
 
     # set email address
@@ -615,7 +637,7 @@ sub UserSearch {
 
     # get data
     return if !$Self->{DBObject}->Prepare(
-        SQL => $SQL,
+        SQL   => $SQL,
         Limit => $Self->{UserSearchListLimit} || $Param{Limit},
     );
 
@@ -648,14 +670,20 @@ sub SetPassword {
 
     # check needed stuff
     if ( !$Param{UserLogin} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need UserLogin!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'Need UserLogin!'
+        );
         return;
     }
 
     # get old user data
     my %User = $Self->GetUserData( User => $Param{UserLogin} );
     if ( !$User{UserLogin} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'No such User!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'No such User!'
+        );
         return;
     }
 
@@ -765,7 +793,10 @@ sub UserLookup {
 
     # check needed stuff
     if ( !$Param{UserLogin} && !$Param{UserID} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need UserLogin or UserID!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'Need UserLogin or UserID!'
+        );
         return;
     }
 
@@ -801,7 +832,10 @@ sub UserLookup {
         }
 
         # set cache
-        $Self->{CacheInternalObject}->Set( Key => $CacheKey, Value => $ID );
+        $Self->{CacheInternalObject}->Set(
+            Key   => $CacheKey,
+            Value => $ID
+        );
 
         return $ID;
     }
@@ -836,7 +870,10 @@ sub UserLookup {
         }
 
         # set cache
-        $Self->{CacheInternalObject}->Set( Key => $CacheKey, Value => $Login );
+        $Self->{CacheInternalObject}->Set(
+            Key   => $CacheKey,
+            Value => $Login
+        );
 
         return $Login;
     }
@@ -924,7 +961,10 @@ sub UserList {
     }
 
     # set cache
-    $Self->{CacheInternalObject}->Set( Key => $CacheKey, Value => \%Users );
+    $Self->{CacheInternalObject}->Set(
+        Key   => $CacheKey,
+        Value => \%Users
+    );
 
     return %Users;
 }
@@ -951,8 +991,7 @@ sub GenerateRandomPassword {
 
     # The list of characters that can appear in a randomly generated password.
     # Note that users can put any character into a password they choose themselves.
-    my @PwChars
-        = ( 0 .. 9, 'A' .. 'Z', 'a' .. 'z', '-', '_', '!', '@', '#', '$', '%', '^', '&', '*' );
+    my @PwChars = ( 0 .. 9, 'A' .. 'Z', 'a' .. 'z', '-', '_', '!', '@', '#', '$', '%', '^', '&', '*' );
 
     # The number of characters in the list.
     my $PwCharsLen = scalar @PwChars;
@@ -985,7 +1024,10 @@ sub SetPreferences {
     # check needed stuff
     for (qw(Key UserID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -1071,7 +1113,10 @@ sub TokenGenerate {
 
     # check needed stuff
     if ( !$Param{UserID} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => "Need UserID!" );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Need UserID!"
+        );
         return;
     }
 
@@ -1113,7 +1158,10 @@ sub TokenCheck {
 
     # check needed stuff
     if ( !$Param{Token} || !$Param{UserID} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need Token and UserID!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'Need Token and UserID!'
+        );
         return;
     }
 
@@ -1153,9 +1201,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.126 $ $Date: 2012-11-20 15:40:39 $
-
-=cut
