@@ -1,9 +1,7 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl
 # --
 # bin/otrs.PackageManager.pl - otrs package manager cmd version
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
-# --
-# $Id: otrs.PackageManager.pl,v 1.10 2010/10/14 08:54:15 bes Exp $
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -17,19 +15,20 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 use strict;
 use warnings;
 
-# use ../ as lib location
 use File::Basename;
-use File::Spec;
 use FindBin qw($RealBin);
 use lib dirname($RealBin);
+use lib dirname($RealBin) . '/Kernel/cpan-lib';
+use lib dirname($RealBin) . '/Custom';
 
+use File::Spec;
 use Getopt::Std;
 
 use Kernel::Config;
@@ -40,10 +39,6 @@ use Kernel::System::DB;
 use Kernel::System::Time;
 use Kernel::System::Package;
 
-# get file version
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.10 $) [1];
-
 # common objects
 my %CommonObject = ();
 $CommonObject{ConfigObject} = Kernel::Config->new();
@@ -71,7 +66,7 @@ if ( !$Opts{f} ) {
 if ( !$Opts{a} ) {
     $Opts{h} = 1;
 }
-if ( $Opts{a} && ( $Opts{a} !~ /^list/ && !$Opts{p} ) ) {
+if ( $Opts{a} && ( $Opts{a} !~ /^(list|reinstall-all)/ && !$Opts{p} ) ) {
     $Opts{h} = 1;
 }
 if ( $Opts{a} && ( $Opts{a} eq 'exportfile' && ( !$Opts{p} || !$Opts{d} ) ) ) {
@@ -83,10 +78,10 @@ if ( $Opts{a} && $Opts{a} eq 'index' ) {
 
 # check needed params
 if ( $Opts{h} ) {
-    print "otrs.PackageManager.pl <Revision $VERSION> - OTRS Package Manager\n";
-    print "Copyright (C) 2001-2010 OTRS AG, http://otrs.org/\n";
+    print "otrs.PackageManager.pl - OTRS Package Manager\n";
+    print "Copyright (C) 2001-2015 OTRS AG, http://otrs.com/\n";
     print
-        "usage: otrs.PackageManager.pl -a list|install|upgrade|uninstall|reinstall|list-repository|file|build|index \n";
+        "usage: otrs.PackageManager.pl -a list|install|upgrade|uninstall|reinstall|reinstall-all|list-repository|file|build|index \n";
     print
         "      [-p package.opm|package.sopm|package|package-version] [-o OUTPUTDIR] [-f FORCE]\n";
     print " user (local):\n";
@@ -94,6 +89,7 @@ if ( $Opts{h} ) {
     print "   otrs.PackageManager.pl -a install -p /path/to/Package-1.0.0.opm\n";
     print "   otrs.PackageManager.pl -a upgrade -p /path/to/Package-1.0.1.opm\n";
     print "   otrs.PackageManager.pl -a reinstall -p Package\n";
+    print "   otrs.PackageManager.pl -a reinstall-all\n";
     print "   otrs.PackageManager.pl -a uninstall -p Package\n";
     print "   otrs.PackageManager.pl -a file -p Kernel/System/File.pm (find package of file)\n";
     print
@@ -263,7 +259,9 @@ if ( $Opts{a} eq 'exportfile' ) {
 
 # build
 if ( $Opts{a} eq 'build' ) {
-    my %Structure = $CommonObject{PackageObject}->PackageParse( String => $FileString, );
+    my %Structure = $CommonObject{PackageObject}->PackageParse(
+        String => $FileString,
+    );
     if ( $Opts{v} && $Opts{v} =~ m/\d{1,4}\.\d{1,4}\.\d{1,4}/ ) {
         $Structure{Version}->{Content} = $Opts{v}
     }
@@ -308,7 +306,9 @@ elsif ( $Opts{a} eq 'uninstall' ) {
 
     # get package file from db
     # parse package
-    my %Structure = $CommonObject{PackageObject}->PackageParse( String => $FileString, );
+    my %Structure = $CommonObject{PackageObject}->PackageParse(
+        String => $FileString,
+    );
 
     # intro screen
     if ( $Structure{IntroUninstallPre} ) {
@@ -340,7 +340,9 @@ elsif ( $Opts{a} eq 'uninstall' ) {
 elsif ( $Opts{a} eq 'install' ) {
 
     # parse package
-    my %Structure = $CommonObject{PackageObject}->PackageParse( String => $FileString, );
+    my %Structure = $CommonObject{PackageObject}->PackageParse(
+        String => $FileString,
+    );
 
     # intro screen
     if ( $Structure{IntroInstallPre} ) {
@@ -372,7 +374,9 @@ elsif ( $Opts{a} eq 'install' ) {
 elsif ( $Opts{a} eq 'reinstall' ) {
 
     # parse package
-    my %Structure = $CommonObject{PackageObject}->PackageParse( String => $FileString, );
+    my %Structure = $CommonObject{PackageObject}->PackageParse(
+        String => $FileString,
+    );
 
     # intro screen
     if ( $Structure{IntroReinstallPre} ) {
@@ -401,10 +405,54 @@ elsif ( $Opts{a} eq 'reinstall' ) {
     }
     exit;
 }
+elsif ( $Opts{a} eq 'reinstall-all' ) {
+
+    my @ReinstalledPackages;
+
+    # loop all locally installed packages
+    for my $Package ( $CommonObject{PackageObject}->RepositoryList() ) {
+
+        # do a deploy check to see if reinstallation is needed
+        my $ReinstallNeeded = $CommonObject{PackageObject}->DeployCheck(
+            Name    => $Package->{Name}->{Content},
+            Version => $Package->{Version}->{Content},
+        );
+
+        if ( !$ReinstallNeeded ) {
+
+            push @ReinstalledPackages, $Package->{Name}->{Content};
+
+            my $FileString = $CommonObject{PackageObject}->RepositoryGet(
+                Name    => $Package->{Name}->{Content},
+                Version => $Package->{Version}->{Content},
+            );
+
+            $CommonObject{PackageObject}->PackageReinstall(
+                String => $FileString,
+                Force  => $Opts{f},
+            );
+        }
+    }
+
+    if (@ReinstalledPackages) {
+        for my $Package (@ReinstalledPackages) {
+            print "Reinstalled: $Package\n";
+        }
+        print "\n";
+    }
+    else {
+        print "No packages needed reinstallation.\n";
+    }
+
+    print "Done.\n";
+    exit;
+}
 elsif ( $Opts{a} eq 'upgrade' ) {
 
     # parse package
-    my %Structure = $CommonObject{PackageObject}->PackageParse( String => $FileString, );
+    my %Structure = $CommonObject{PackageObject}->PackageParse(
+        String => $FileString,
+    );
 
     # intro screen
     if ( $Structure{IntroUpgradePre} ) {
@@ -435,7 +483,10 @@ elsif ( $Opts{a} eq 'upgrade' ) {
 }
 elsif ( $Opts{a} eq 'list' ) {
     for my $Package ( $CommonObject{PackageObject}->RepositoryList() ) {
-        my %Data = _MessageGet( Info => $Package->{Description}, Reformat => 'No' );
+        my %Data = _MessageGet(
+            Info     => $Package->{Description},
+            Reformat => 'No'
+        );
         print "+----------------------------------------------------------------------------+\n";
         print "| Name:        $Package->{Name}->{Content}\n";
         print "| Version:     $Package->{Version}->{Content}\n";
@@ -515,13 +566,17 @@ elsif ( $Opts{a} eq 'list-repository' ) {
     exit;
 }
 elsif ( $Opts{a} eq 'p' ) {
-    my @Data = $CommonObject{PackageObject}->PackageParse( String => $FileString, );
+    my @Data = $CommonObject{PackageObject}->PackageParse(
+        String => $FileString,
+    );
     for my $Tag (@Data) {
         print STDERR "Tag: $Tag->{Type} $Tag->{Tag} $Tag->{Content}\n";
     }
 }
 elsif ( $Opts{a} eq 'parse' ) {
-    my %Structure = $CommonObject{PackageObject}->PackageParse( String => $FileString, );
+    my %Structure = $CommonObject{PackageObject}->PackageParse(
+        String => $FileString,
+    );
     for my $Key ( sort keys %Structure ) {
         if ( ref( $Structure{$Key} ) eq 'ARRAY' ) {
             for my $Data ( @{ $Structure{$Key} } ) {
@@ -598,8 +653,7 @@ sub BuildPackageIndex {
                     print STDERR "ERROR: Can't open $OrigFile: $!\n";
                     exit 1;
                 }
-                my %Structure
-                    = $CommonObject{PackageObject}->PackageParse( String => ${$ContentRef} );
+                my %Structure = $CommonObject{PackageObject}->PackageParse( String => ${$ContentRef} );
                 my $XML = $CommonObject{PackageObject}->PackageBuild( %Structure, Type => 'Index' );
                 print "<Package>\n";
                 print $XML;
@@ -633,7 +687,7 @@ sub _MessageGet {
         }
     }
     if ( !$Param{Reformat} || $Param{Reformat} ne 'No' ) {
-        $Title       =~ s/(.{4,78})(?:\s|\z)/| $1\n/gm;
+        $Title =~ s/(.{4,78})(?:\s|\z)/| $1\n/gm;
         $Description =~ s/^\s*//mg;
         $Description =~ s/\n/ /gs;
         $Description =~ s/\r/ /gs;
