@@ -2,8 +2,6 @@
 // Core.Agent.TicketAction.js - provides functions for all ticket action popups
 // Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 // --
-// $Id: Core.Agent.TicketAction.js,v 1.15.2.2 2012/08/14 10:06:42 mg Exp $
-// --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
 // did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
@@ -101,6 +99,25 @@ Core.Agent.TicketAction = (function (TargetNS) {
         $Element.val(NewValue);
     }
 
+    /**
+     * @function
+     * @private
+     * @description Mark the primary customer
+     */
+    function MarkPrimaryCustomer() {
+        $('.CustomerContainer').children('div').each(function() {
+            var $InputObj = $(this).find('.CustomerTicketText'),
+                $RadioObj = $(this).find('.CustomerTicketRadio');
+
+            if ($RadioObj.prop('checked')) {
+                $InputObj.addClass('MainCustomer');
+            }
+            else {
+                $InputObj.removeClass('MainCustomer');
+            }
+        });
+    }
+
     /**
      * @function
      * @description
@@ -125,6 +142,13 @@ Core.Agent.TicketAction = (function (TargetNS) {
             OpenCustomerDialog();
             return false;
         });
+
+        // Subscribe to the reloading of the CustomerInfo box to
+        // specially mark the primary customer
+        MarkPrimaryCustomer();
+        Core.App.Subscribe('Event.Agent.CustomerSearch.GetCustomerInfo.Callback', function() {
+            MarkPrimaryCustomer();
+        });
     };
 
     /**
